@@ -12,3 +12,8 @@ Event when application is stopped
 
 BeforeDatabaseEngineConfiguration = 2
 AfterDatabaseEngineConfiguration = 3
+BeforeInitStatic = 4
+AfterInitStatic = 5
+BeforeApplicationStarted = 6
+BeforeInitServer = 7
+AfterInitServer = 8
